==> jc-1.4.0.tar.gz: java/lang/reflect/Proxy__24ProxyType.h <==
// final class java.lang.reflect.Proxy$ProxyType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a07312605110b591 java_lang_reflect_Proxy__24ProxyType

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_reflect_Proxy__24ProxyType_H_
#define _JC_java_lang_reflect_Proxy__24ProxyType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_lang_reflect_Proxy__24ProxyType$sub_refs	_jc_java_lang_reflect_Proxy__24ProxyType$sub_refs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxyType$sub_nonrefs	_jc_java_lang_reflect_Proxy__24ProxyType$sub_nonrefs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxyType$refs	_jc_java_lang_reflect_Proxy__24ProxyType$refs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxyType$nonrefs	_jc_java_lang_reflect_Proxy__24ProxyType$nonrefs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxyType$object	_jc_java_lang_reflect_Proxy__24ProxyType$object;

typedef const struct _jc_java_lang_reflect_Proxy__24ProxyType$vmethods	_jc_java_lang_reflect_Proxy__24ProxyType$vmethods;
typedef const struct _jc_java_lang_reflect_Proxy__24ProxyType$vtable	_jc_java_lang_reflect_Proxy__24ProxyType$vtable;
typedef const struct _jc_java_lang_reflect_Proxy__24ProxyType$vtype	_jc_java_lang_reflect_Proxy__24ProxyType$vtype;

// Constructors
extern void _jc_java_lang_reflect_Proxy__24ProxyType$method$_init$ca3640be874db47c(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxyType$object *, struct _jc_java_lang_ClassLoader$object *, struct _jc_object_array *);

// Virtual methods
extern jboolean _jc_java_lang_reflect_Proxy__24ProxyType$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxyType$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_lang_reflect_Proxy__24ProxyType$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxyType$object *);

// Virtual method descriptors
extern _jc_method _jc_java_lang_reflect_Proxy__24ProxyType$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_lang_reflect_Proxy__24ProxyType$method_info$hashCode$53152098849316df;

// Static methods
extern jboolean _jc_java_lang_reflect_Proxy__24ProxyType$method$sameTypes$c13327962debbdc7(_jc_env *, struct _jc_object_array *, struct _jc_object_array *);

// Virtual methods structure
struct _jc_java_lang_reflect_Proxy__24ProxyType$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxyType$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxyType$object *);
};

// Vtable
struct _jc_java_lang_reflect_Proxy__24ProxyType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_reflect_Proxy__24ProxyType$vmethods	java_lang_reflect_Proxy__24ProxyType;
};

// Vtype
struct _jc_java_lang_reflect_Proxy__24ProxyType$vtype {
	_jc_type			type;
	_jc_java_lang_reflect_Proxy__24ProxyType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_reflect_Proxy__24ProxyType$sub_refs {
	struct _jc_java_lang_ClassLoader$object	*loader;
	_jc_object_array	*interfaces;
};

// Reference instance fields (object)
struct _jc_java_lang_reflect_Proxy__24ProxyType$refs {
    _jc_java_lang_reflect_Proxy__24ProxyType$sub_refs	java_lang_reflect_Proxy__24ProxyType;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_reflect_Proxy__24ProxyType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_reflect_Proxy__24ProxyType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_reflect_Proxy__24ProxyType$sub_nonrefs	java_lang_reflect_Proxy__24ProxyType;
};

// Object instance structure
struct _jc_java_lang_reflect_Proxy__24ProxyType$object {
	_jc_java_lang_reflect_Proxy__24ProxyType$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_reflect_Proxy__24ProxyType$vtype	*vtype;
	_jc_java_lang_reflect_Proxy__24ProxyType$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_reflect_Proxy__24ProxyType$vtype _jc_java_lang_reflect_Proxy__24ProxyType$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_reflect_Proxy__24ProxyType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_reflect_Proxy__24ProxyType$class_object;

#endif	/* _JC_java_lang_reflect_Proxy__24ProxyType_H_ */

==> jc-1.4.6.tar.gz: java/lang/reflect/Proxy__24ProxyType.h <==
// final class java.lang.reflect.Proxy$ProxyType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a07312605110b591 java_lang_reflect_Proxy__24ProxyType

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_reflect_Proxy__24ProxyType_H_
#define _JC_java_lang_reflect_Proxy__24ProxyType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_lang_reflect_Proxy__24ProxyType$sub_refs	_jc_java_lang_reflect_Proxy__24ProxyType$sub_refs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxyType$sub_nonrefs	_jc_java_lang_reflect_Proxy__24ProxyType$sub_nonrefs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxyType$refs	_jc_java_lang_reflect_Proxy__24ProxyType$refs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxyType$nonrefs	_jc_java_lang_reflect_Proxy__24ProxyType$nonrefs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxyType$object	_jc_java_lang_reflect_Proxy__24ProxyType$object;

typedef const struct _jc_java_lang_reflect_Proxy__24ProxyType$vmethods	_jc_java_lang_reflect_Proxy__24ProxyType$vmethods;
typedef const struct _jc_java_lang_reflect_Proxy__24ProxyType$vtable	_jc_java_lang_reflect_Proxy__24ProxyType$vtable;
typedef const struct _jc_java_lang_reflect_Proxy__24ProxyType$vtype	_jc_java_lang_reflect_Proxy__24ProxyType$vtype;

// Constructors
extern void _jc_java_lang_reflect_Proxy__24ProxyType$method$_init$ca3640be874db47c(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxyType$object *, struct _jc_java_lang_ClassLoader$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_lang_reflect_Proxy__24ProxyType$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxyType$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_lang_reflect_Proxy__24ProxyType$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxyType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_reflect_Proxy__24ProxyType$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_lang_reflect_Proxy__24ProxyType$method_info$hashCode$53152098849316df;

// Static methods
extern jboolean _jc_java_lang_reflect_Proxy__24ProxyType$method$sameTypes$c13327962debbdc7(_jc_env *, struct _jc_object_array *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_reflect_Proxy__24ProxyType$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxyType$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxyType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_reflect_Proxy__24ProxyType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_reflect_Proxy__24ProxyType$vmethods	java_lang_reflect_Proxy__24ProxyType;
};

// Vtype
struct _jc_java_lang_reflect_Proxy__24ProxyType$vtype {
	_jc_type			type;
	_jc_java_lang_reflect_Proxy__24ProxyType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_reflect_Proxy__24ProxyType$sub_refs {
	struct _jc_java_lang_ClassLoader$object	*loader;
	_jc_object_array	*interfaces;
};

// Reference instance fields (object)
struct _jc_java_lang_reflect_Proxy__24ProxyType$refs {
    _jc_java_lang_reflect_Proxy__24ProxyType$sub_refs	java_lang_reflect_Proxy__24ProxyType;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_reflect_Proxy__24ProxyType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_reflect_Proxy__24ProxyType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_reflect_Proxy__24ProxyType$sub_nonrefs	java_lang_reflect_Proxy__24ProxyType;
};

// Object instance structure
struct _jc_java_lang_reflect_Proxy__24ProxyType$object {
	_jc_java_lang_reflect_Proxy__24ProxyType$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_reflect_Proxy__24ProxyType$vtype	*vtype;
	_jc_java_lang_reflect_Proxy__24ProxyType$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_reflect_Proxy__24ProxyType$vtype _jc_java_lang_reflect_Proxy__24ProxyType$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_reflect_Proxy__24ProxyType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_reflect_Proxy__24ProxyType$class_object;

#endif	/* _JC_java_lang_reflect_Proxy__24ProxyType_H_ */
